# rankhub - is a Python package to generate GitHub users rankings

[![Python Version](https://img.shields.io/pypi/pyversions/rankhub.svg)](https://pypi.org/project/rankhub/)
[![PyPi Version](https://img.shields.io/pypi/v/rankhub.svg)](https://pypi.org/project/rankhub/)
[![Package Status](https://img.shields.io/pypi/status/rankhub.svg)](https://pypi.org/project/rankhub/)
[![Build Status](https://img.shields.io/travis/alvarob96/rankhub/master.svg?label=Travis%20CI&logo=travis&logoColor=white)](https://travis-ci.org/alvarob96/rankhub)

## Introduction

This project is intended to be a Python package in order to retrieve data from GitHub using 
its public API with an application token. Currently, as this project is under-development,
a simple use-case is proposed in order to retrieve data from Salamanca (Spain) GitHub users 
as to generate a ranking with the most active users in public repositories throughout 2019.

## Top GitHub Users from Salamanca (Spain) sorted by Public Contributions throughout 2019

As already mentioned, this ranking contains all the GitHub users from Salamanca sorted by the
amount of public contributions just between 01/01/2019 until the current date 21/09/2019.

| Rank | User | Avatar | Public Contributions | Most Used Language | Used Languages |
|------|------|--------|----------------------|--------------------|----------------|
| 1 | <img src='https://avatars0.githubusercontent.com/u/4302127?v=4&s=64' width='64'> | [Emirodgar](https://github.com/Emirodgar) | 2187 | HTML| HTML, JavaScript, CSS |
| 2 | <img src='https://avatars1.githubusercontent.com/u/32566274?v=4&s=64' width='64'> | [tomhendra](https://github.com/tomhendra) | 851 | JavaScript| JavaScript, CSS, HTML |
| 3 | <img src='https://avatars2.githubusercontent.com/u/2938045?v=4&s=64' width='64'> | [cbjuan](https://github.com/cbjuan) | 360 | Python| JavaScript, HTML, Jupyter Notebook, Python, Shell |
| 4 | <img src='https://avatars3.githubusercontent.com/u/36760800?v=4&s=64' width='64'> | [alvarob96](https://github.com/alvarob96) | 293 | Jupyter Notebook| Jupyter Notebook, Python |
| 5 | <img src='https://avatars3.githubusercontent.com/u/33935947?v=4&s=64' width='64'> | [JParzival](https://github.com/JParzival) | 216 | Jupyter Notebook| JavaScript, Python, Jupyter Notebook, Java, TypeScript, R, PHP, HTML |

This is just the leading Top 5 GitHub users from the generated ranking, so the complete ranking 
can be found in [salamanca/](https://github.com/alvarob96/rankhub/blob/master/salamanca) in both
JSON and Markdown format.

Note that both the ranking and the package will be updated in order to create a 2019 ranking resume
at the end of the year! So make sure to watch and star the repo in order to get tuned for updates!

## Contribute

As this is an open source project it is open to contributions, bug reports, bug fixes, documentation improvements, 
enhancements and ideas.

Also there is an open tab of [issues](https://github.com/alvarob96/rankhub/issues) where anyone can contribute opening 
new issues if needed or navigate through them in order to solve them or contribute to its solving.

## Disclaimer

This project is made with research purposes only, so to create a Python package to make it 
usable with Python in order to retrieve GitHub stats that can further be used for data analysis.

As the use case is just an approach, note that it can have somer errors related to data retrieval
from GitHub. Also the generated ranking has no intention of generating any kind of competition
between the involved people in the generated ranking/s.